@@ -12,7 +12,8 @@ class DataDogTelemeter:
     def __init__(self):
         self.configuration = Configuration()
 
-    def guage(self, metric, *values):
+    def gauge(self, metric, *values):
+        pass
 
 # Enter a context with an instance of the API client
 with ApiClient(configuration) as api_client:
